# PigLatin.py
# (c) Alan Gilfoy, 2007-2008

def toPigLatin(english_input):
    '''
    Converts an English-langauge string into a list, and the list contains the Pig Latin words for each word in the inputted English string.

    >>> toPigLatin("Always look on the bright side of life")
    'Alwaysay ooklay onay ethay ightbray idesay ofay ifelay'
    >>> toPigLatin("This parrot is not dead. It's pining for the fjords.")
    "isThay arrotpay isay otnay eadday. It'say iningpay orfay ethay jordsfay."
    >>> toPigLatin("And now for something completely different")
    'Anday ownay orfay omethingsay ompletelycay ifferentday'
    '''

    words = english_input.split()

    pig_output = []

    two_letter_sounds = "br ch cr dr fr gr pl qu sc sh sp sr th wh"
    # the spaces are important
    # the block of code that uses this variable 'scans' for certain 2-letter combinations in the inputted English word(s)
    # if mashed together, a two-letter sequence consisting of
    # the second letter of one pair, and the first of the next, would be interpreted as a 'two-letter sound',
    # even though the two-letter pairs are intended as separate entities.
    #
    # I'll illustrate this concept with a simplified version of this list: "qu sh th".
    # Separated, only 'qu', 'sh' and 'th' are seen by the program as 'two-letter sounds'. (as is approriate).
    # Mashed together as "qushth", 'us' and 'ht' would also been seen by the program as 'two-letter sounds'.
    # (which is not accurate).
    #
    # It doesn't matter to the program that the 2-letter sounds are in alphabetical order, I just like the way that looks.

    vowels = "aeiou"

    letters = "abcdefghijklmnopqrstuvwxyz"

    numbers = "1234567890"

    for word in words:

        if word[0] in numbers:
            number_result_word = word
            pig_output.append(number_result_word)

        if word[-1].lower() in letters and word[0] not in numbers:

            #processes words starting with vowels
            if word[0].lower() in vowels:
                vowel_result_word = word
                vowel_result_word = vowel_result_word + "ay"
                pig_output.append(vowel_result_word)

            # processes words starting with two-letter sounds

            if word[0:2].lower() in two_letter_sounds:
                two_letter_sound_result_word = word[2:] + word[0:2] + "ay"
                pig_output.append(two_letter_sound_result_word)

            # processes everything else, which should mean words that don't start with vowels or double-letter sounds
            
            if word[0].lower() not in vowels and word[0:2].lower() not in two_letter_sounds:
                other_result_word = word[1:] + word[0] + "ay"
                pig_output.append(other_result_word)

        if word[-1].lower() not in letters and word[0] not in numbers:

            # similar to 'if word[-1].lower() in letters:'

            last_character = word[-1]

            word = word[0:(len(word)-1)]

            if word[0].lower() in vowels:
                vowel_result_word = word
                vowel_result_word = vowel_result_word + "ay" + last_character
                pig_output.append(vowel_result_word)

            if word[0:2].lower() in two_letter_sounds:
                two_letter_sound_result_word = word[2:] + word[0:2] + "ay" + last_character
                pig_output.append(two_letter_sound_result_word)
            
            if word[0].lower() not in vowels and word[0:2].lower() not in two_letter_sounds:
                other_result_word = word[1:] + word[0] + "ay" + last_character
                pig_output.append(other_result_word)

        final_pig_output = ' '.join(pig_output)

    return final_pig_output

if __name__ == '__main__':
    print "This a module, a program that is designed to be used by another program."
    print "This particular module I designed to be used with PigLatinConverter, which should be in the same folder as this file."
    import doctest
    doctest.testmod()
    a = raw_input("Type in something, and hit Enter, and the program will shut down.")
